# Developer guide

Welcome to the **SplitterMR Python API** reference.

![SplitterMR architecture diagram](https://raw.githubusercontent.com/andreshere00/Splitter_MR/refs/heads/main/assets/architecture_splitter_mr.svg)

## Documentation

### Reader component documentation

[Link](./reader.md)

### Splitter component documentation

[Link](./splitter.md)
